# Shared / Utilities

## Macros

::: whatrecord.macro

## PV Graphing

::: whatrecord.graph

## Shared

::: whatrecord.common

## Miscellaneous

::: whatrecord.cache
::: whatrecord.format
::: whatrecord.graphql
::: whatrecord.settings
::: whatrecord.util
